==> mozc_1.2.855.102.orig.tar.gz: mozc-1.2.855.102/gui/character_pad/character_pad_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>CharacterPalette</name>
    <message>
        <location filename="character_palette.ui" line="14"/>
        <source>Mozc Character Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_palette.ui" line="61"/>
        <source>Largest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_palette.ui" line="66"/>
        <source>Larger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_palette.ui" line="71"/>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_palette.ui" line="76"/>
        <source>Smaller</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_palette.ui" line="81"/>
        <source>Smallest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_palette.ui" line="123"/>
        <source>JIS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_palette.ui" line="128"/>
        <source>Unicode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HandWriting</name>
    <message>
        <location filename="hand_writing.ui" line="14"/>
        <source>Mozc Hand Writing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="hand_writing.ui" line="61"/>
        <source>Largest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="hand_writing.ui" line="66"/>
        <source>Larger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="hand_writing.ui" line="71"/>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="hand_writing.ui" line="76"/>
        <source>Smaller</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="hand_writing.ui" line="81"/>
        <source>Smallest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="hand_writing.ui" line="116"/>
        <source>clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="hand_writing.ui" line="123"/>
        <source>revert</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="hand_writing_canvas.cc" line="118"/>
        <source>Draw a character here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="selection_handler.cc" line="27"/>
        <source>Note</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="selection_handler.cc" line="28"/>
        <source> is sent to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="unicode_util.cc" line="187"/>
        <source>Kun Reading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="unicode_util.cc" line="192"/>
        <source>On Reading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="unicode_util.cc" line="197"/>
        <source>Radical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="unicode_util.cc" line="204"/>
        <source>Total Strokes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="unicode_util.cc" line="209"/>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="unicode_util.cc" line="215"/>
        <source>Unicode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mozc::gui::HandWritingCanvas</name>
    <message>
        <location filename="hand_writing_canvas.cc" line="48"/>
        <location filename="hand_writing_canvas.cc" line="56"/>
        <source>Mozc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="hand_writing_canvas.cc" line="49"/>
        <source>Failed to load model file %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="hand_writing_canvas.cc" line="57"/>
        <source>model file %1 is broken.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mozc_1.4.1003.102.orig.tar.gz: mozc-1.4.1003.102/gui/character_pad/character_pad_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>CharacterPalette</name>
    <message>
        <location filename="character_palette.ui" line="14"/>
        <source>Mozc Character Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_palette.ui" line="61"/>
        <source>Largest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_palette.ui" line="66"/>
        <source>Larger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_palette.ui" line="71"/>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_palette.ui" line="76"/>
        <source>Smaller</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_palette.ui" line="81"/>
        <source>Smallest</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HandWriting</name>
    <message>
        <location filename="hand_writing.ui" line="14"/>
        <source>Mozc Hand Writing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="hand_writing.ui" line="61"/>
        <source>Largest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="hand_writing.ui" line="66"/>
        <source>Larger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="hand_writing.ui" line="71"/>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="hand_writing.ui" line="76"/>
        <source>Smaller</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="hand_writing.ui" line="81"/>
        <source>Smallest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="hand_writing.ui" line="116"/>
        <source>clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="hand_writing.ui" line="123"/>
        <source>revert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="hand_writing.ui" line="146"/>
        <source>Local</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="hand_writing.ui" line="151"/>
        <source>Cloud</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="hand_writing_canvas.cc" line="100"/>
        <source>Draw a character here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="selection_handler.cc" line="27"/>
        <source>Note</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="selection_handler.cc" line="28"/>
        <source> is sent to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="unicode_util.cc" line="187"/>
        <source>Kun Reading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="unicode_util.cc" line="192"/>
        <source>On Reading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="unicode_util.cc" line="211"/>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="unicode_util.cc" line="217"/>
        <source>Unicode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mozc::gui::HandWriting</name>
    <message>
        <location filename="hand_writing.cc" line="277"/>
        <source>Cloud handwriting recognition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="hand_writing.cc" line="280"/>
        <source>This feature improve the accuracy of handwriting recognition by using a Google web service. To do so, your handwriting strokes will be securely sent to Google. Do you want to use Cloud handwriting?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
